#!/bin/sh
# *******************************************************************************
#  Лицензионные материалы - собственность IBM
#  (c) Copyright IBM Corporation 2006, 2011. Все права защищены.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Определите переменные среды, соответствующие параметрам
# # сценария ccm_upgrade.sh, и их значения по умолчанию
# #
# #===========================================================
# #
# # Этот файл считывается в начале каждого выполнения сценария
# # ccm_upgrade.sh. Для каждого допустимого параметра он
# # инициализирует переменную среды предопределенным
# # значением по умолчанию.
# #
# # Пользователям может потребоваться изменить значение по
# # умолчанию, чтобы запускать ccm_upgrade.sh со своими
# # значениями, не вводя параметр и его значение вручную
# # в командной строке.
# #
# # ПРЕДУПРЕЖДЕНИЕ:
# # Для некоторых приложений требуется указывать не все
# # переменные.  Внимательно ознакомьтесь с комментарием
# # перед изменением значения.
# #
# #############################################################

# Параметр: -oldApplicationHome
# Формат: -oldApplicationHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу приложения в установке
#  версии 2.x или 3.0.x.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - это обязательный параметр
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf',
#    например: /Jazz/IBM/RTC_2.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Параметр: -applicationContextRoot
# Формат: -applicationContextRoot<корень>
# Описание:
# 	Корневой контекст приложения сервера версии 2.x или 3.0.x.
# Значение по умолчанию:
# 	jazz (2.x), ccm (3.0.1)
# Ограничения:
#  - <корень> должен быть допустимым именем каталога
#   (то есть без начального символа косой черты)
#
APPLICATION_CONTEXT_ROOT=

# Параметр: -oldApplicationVersion
# Формат: -oldApplicationVersion <версия>
# Описание:
# 	Обновляемая версия 3.x. По умолчанию, версия определяется командой
# 	repotools -version в прежнем приложении.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - не следует указывать при обновлении версии 2.x
#  - значение версии должно быть полным, например 3.0.0 или 3.0.1
#
OLD_APPLICATION_VERSION=

# Параметр: -updateTomcatFiles
# Формат: -updateTomcatFiles <yes | no>
# Описание:
# 	Разрешает/запрещает обновление файлов конфигурации Tomcat.
# Значение по умолчанию:
# 	yes
# Ограничения:
#  - Допустимы только значения 'yes' и 'no'
#
UPDATE_TOMCAT_FILES=yes

# Параметр: -oldTomcatHome
# Формат: -oldTomcatHome <путь-к-каталогу>
# Описание:
# 	Полный путь к корневому каталогу Tomcat в установке версии 2.x или 3.0.x.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Должен задавать существующий каталог
#
OLD_TOMCAT_HOME=

# Параметр: -newApplicationHome
# Формат: -newApplicationHome <путь-к-каталогу>
# Описание:
# 	Путь к домашнему каталогу приложения в установке версии 3.0.1.2.
# Значение по умолчанию:
# 	conf
# Ограничения:
#  - Допустим только при обновлении RTC, QM и RM
#  - Если допустим, то является обязательным
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf',
#    например: /Jazz/IBM/RTC_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Параметр: -newJTSHome
# Формат: -newJTSHome <путь-к-каталогу>
# Описание:
# 	Путь к каталогу конфигурации сервера JTS в версии 3.0.1.2
# Значение по умолчанию:
# 	Новый домашний каталог приложения
# Ограничения:
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf'
#
NEW_JTS_HOME=

# Параметр: -jtsContextRoot
# Формат: -jtsContextRoot <корень>
# Описание:
# 	Корневой контекст сервера 3.0.1.2 JTS.
# Значение по умолчанию:
# 	jts
# Ограничения:
#  - <корень> должен быть допустимым именем каталога
#   (то есть без начального символа косой черты)
#
JTS_CONTEXT_ROOT=jts

# Параметр: -newApplicationTomcatHome
# Формат: -newApplicationTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к корневому каталогу Tomcat приложения в установке версии 3.0.1.2.
# Значение по умолчанию:
# 	<нет>
#
NEW_TOMCAT_HOME=

# Параметр: -newJTSTomcatHome
# Формат: -newJTSTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к корневому каталогу Tomcat JTS в установке версии 3.0.1.2.
# Значение по умолчанию:
# 	<нет>
#
NEW_JTS_TOMCAT_HOME=

# Параметр: -noPrompt
# Формат: -noPrompt
# Описание:
# 	Не показывать приглашение перед созданием или изменением таблиц
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Параметр: -noVerify
# Формат: -noVerify
# Описание:
# 	Не выполнять проверку файлов teamserver.properties.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Параметр: -overwrite
# Формат: -overwrite
# Описание:
# 	Включает режим замены существующих файлов.
# Значение по умолчанию:
# 	no
# Ограничения:
#  - Допустимо только пустое значение и значение 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Параметр: -importFromFile
# Формат: -importFromFile <путь-к-файлу>
# Описание:
# 	Импорт данных из файла tar, экспортированного из версии 2.x или 3.0.x.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Путь должен указывать на существующий допустимый файл
#
IMPORT_FROM_FILE=

# Параметр: -noStepPrompt
# Формат: -noStepPrompt
# Описание:
# 	Не выводить запрос перед выполнением шага.
# Значение по умолчанию:
# 	false
# Ограничения:
#  - Допустимы только значения 'true' и 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
